/*
 * Sicherheitsunterweisung
 * Copyright (C) 2023  Jason Streifling
 *
 * This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package main

import (
	"html/template"
	"log"
	"net/http"

	"streifling.com/jason/sicherheitsunterweisung/packages/data"
	"streifling.com/jason/sicherheitsunterweisung/packages/session"
)

func main() {
	db, err := data.OpenDB("sicherheitsunterweisung")
	if err != nil {
		log.Fatalln(err)
	}

	mux := session.NewMux()
	sessions := make([]*session.Session, 0)
	sessionChan := make(chan *session.Session)

	mux.Handle("/static/", http.StripPrefix("/static/", http.FileServer(http.Dir("static/"))))
	mux.HandleFunc("/", func(w http.ResponseWriter, r *http.Request) {
		template.Must(template.ParseFiles("templates/index.html", "templates/login.html")).Execute(w, nil)
	})
	mux.HandleFunc("/internal-login/", session.HandleInternalLogin(db, &sessions, sessionChan))
	mux.HandleFunc("/external-login/", session.HandleExternalLogin(&sessions))

	go mux.HandleSessions(db, sessionChan, &sessions)

	log.Fatalln(http.ListenAndServe(":8080", mux))
}
